dailp::comment

Enum CommentParentType

source
pub enum CommentParentType {
    Word,
    Paragraph,
}
An enum listing the possible types that a comment could be attached to

Variants



Word

A comment attached to a word



Paragraph

A comment attached to a paragraph

Implementations

source

impl CommentParentType

source

pub async fn resolve( &self, db: &Database, parent_id: &Uuid, ) -> FieldResult<CommentParent>

Get the actual object referenced by this type, given an id