pub enum CommentType {
Story,
Suggestion,
Question,
}Expand description
A type describing the kind of comment being made
Variants
Story
A comment sharing a story or similar information related to the parent object
Suggestion
A comment with a suggestion to improve the information shown about the parent object
Question
A comment asking a question about our information regarding the parent object