pub enum CherokeeOrthography {
Taoc,
Crg,
Learner,
}Expand description
One representation of Cherokee phonology. There are several different writing systems for Cherokee phonology and we want to convert between them. This type enumerates all of the systems that we support and provides conversion from our internal orthography into any of these.
Variants
Taoc
The t/th system for transcribing the Cherokee syllabary. This orthography is favored by linguists as it is segmentally more accurate.
Crg
The d/t system for transcribing the Cherokee syllabary. This orthography is favored by speakers. TODO Option for /ts/ instead of /j/ TODO Option for /qu/ instead of /gw/ or /kw/
Learner
Simplified system that uses d/t without tones, a compromise intended for language learners. qu and ts
Implementations
sourceimpl CherokeeOrthography
impl CherokeeOrthography
sourcepub fn convert(&self, input: &str) -> String
pub fn convert(&self, input: &str) -> String
Convert from the input string in DAILP internal orthography (which is similar to TAOC) into this orthography.
sourcepub fn similar_syllabary_strings(original: &str) -> Vec<String>
pub fn similar_syllabary_strings(original: &str) -> Vec<String>
Return a list of possible misspellings of the given syllabary string, based on which characters look the most similar.