pub enum ContributorRole {
Transcriber,
Translator,
Annotator,
CulturalAdvisor,
Author,
Editor,
}Expand description
A contributor can have to any number of roles, which define most of their contributions to the associated item (add or revise as needed)
Variants
Transcriber
Typed or transcribed handwritten materials
Translator
Translated text into another language
Annotator
Added linguistic, cultural, etc. annotations
CulturalAdvisor
Provided cultural context for a document
Author
Author of a document
Editor
Edited a document
Implementations
sourceimpl ContributorRole
impl ContributorRole
sourcepub fn from_option_str(s: &str) -> Option<Self>
pub fn from_option_str(s: &str) -> Option<Self>
Attempts to parse a string into a ContributorRole, returning None if parsing fails
sourcepub fn to_option_string(role: &Option<ContributorRole>) -> Option<String>
pub fn to_option_string(role: &Option<ContributorRole>) -> Option<String>
Converts a ContributorRole into its string representation