pub enum DocumentType {
Reference,
Corpus,
}Expand description
The kind of a document in terms of what body it lives within. A reference document is a dictionary or grammar for example, while a corpus document might be a letter, journal, or notice.
Variants
Reference
Reference document, like a dictionary or grammar
Corpus
Corpus text: a letter, journal, book, story, meeting minutes, etc.