pub fn convert_udb(input: &str) -> PhonemicStringExpand description
Converts a given phonemic string from the Uchihara representation to the DAILP representation. For example: “a:!” => “áá”
pub fn convert_udb(input: &str) -> PhonemicStringConverts a given phonemic string from the Uchihara representation to the DAILP representation. For example: “a:!” => “áá”