dailp

Function is_root_morpheme

source
pub fn is_root_morpheme(s: &str) -> bool
Is the given gloss for a root morpheme? This is a crude calculation that just checks if there are any lowercase characters. Convention says that typically functional morpheme tags are all uppercase (plus numbers and punctuation), so having lowercase characters indicates a lexical morpheme gloss.