dailp

Function root_noun_surface_form

source
pub fn root_noun_surface_form(
    position: &PositionInDocument,
    date: &Date,
    cols: &mut impl Iterator<Item = String>,
    has_comment: bool,
) -> Option<AnnotatedForm>
TODO Convert all phonemic representations into the TAOC/DAILP format. TODO Store forms in any format with a tag defining the format so that GraphQL can do the conversion instead of the migration process.