dailp

Struct AnnotatedForm

source
pub struct AnnotatedForm {
Show 13 fields pub id: Option<Uuid>, pub source: String, pub normalized_source: Option<String>, pub simple_phonetics: Option<String>, pub phonemic: Option<String>, pub segments: Option<Vec<WordSegment>>, pub english_gloss: Vec<String>, pub commentary: Option<String>, pub line_break: Option<i32>, pub page_break: Option<i32>, pub position: PositionInDocument, pub date_recorded: Option<Date>, pub ingested_audio_track: Option<AudioSlice>,
}
A single word in an annotated document. One word contains several layers of interpretation, including the original source text, multiple layers of linguistic annotation, and annotator notes. TODO Split into two types, one for migration and one for SQL + GraphQL

Fields

id: Option<Uuid>

Unique identifier of this form

source: String

Original source text

normalized_source: Option<String>

A normalized version of the word

simple_phonetics: Option<String>

Romanized version of the word for simple phonetic pronunciation

phonemic: Option<String>

Underlying phonemic representation of this word

segments: Option<Vec<WordSegment>>

Morphemic segmentation of the form that includes a phonemic representation and gloss for each

english_gloss: Vec<String>

English gloss for the whole word

commentary: Option<String>

Further details about the annotation layers, including uncertainty

line_break: Option<i32>

The character index of a mid-word line break, if there is one

page_break: Option<i32>

The character index of a mid-word page break, if there is one

position: PositionInDocument

Position of the form within the context of its parent document

date_recorded: Option<Date>

The date and time this form was recorded

ingested_audio_track: Option<AudioSlice>

The audio for this word that was ingested from GoogleSheets, if there is any.

Implementations

source

impl AnnotatedForm

source

pub async fn source(&self, ctx: &Context<'_>) -> Result<&String>

source

pub async fn normalized_source( &self, ctx: &Context<'_>, ) -> Result<&Option<String>>

source

pub async fn phonemic(&self, ctx: &Context<'_>) -> Result<&Option<String>>

source

pub async fn english_gloss(&self, ctx: &Context<'_>) -> Result<&Vec<String>>

source

pub async fn commentary(&self, ctx: &Context<'_>) -> Result<&Option<String>>

source

pub async fn line_break(&self, ctx: &Context<'_>) -> Result<&Option<i32>>

source

pub async fn page_break(&self, ctx: &Context<'_>) -> Result<&Option<i32>>

source

pub async fn position(&self, ctx: &Context<'_>) -> Result<&PositionInDocument>

source

pub async fn date_recorded(&self, ctx: &Context<'_>) -> Result<&Option<Date>>

source

pub async fn ingested_audio_track( &self, ctx: &Context<'_>, ) -> Result<&Option<AudioSlice>>

source

impl AnnotatedForm

source

pub fn find_root(&self) -> Option<&WordSegment>

Look for a root morpheme in the word using crude case checks.

source

pub fn find_morpheme(&self, gloss: &str) -> Option<&WordSegment>

Find a morpheme within this word with the given exact gloss.

source

pub fn is_unresolved(&self) -> bool

Are there any unidentified segments within this word? Just checks if there are morphemes or glosses consisting of a question mark “?”