pub struct AudioSlice {
pub slice_id: Option<AudioSliceId>,
pub resource_url: String,
pub parent_track: Option<DocumentAudioId>,
pub recorded_at: Option<Date>,
pub recorded_by: Option<User>,
pub include_in_edited_collection: bool,
pub edited_by: Option<User>,
pub annotations: Option<Vec<AudioSlice>>,
pub index: i32,
pub start_time: Option<i32>,
pub end_time: Option<i32>,
}Expand description
A segment of audio representing a document, word, phrase, or other audio unit
Fields
slice_id: Option<AudioSliceId>The unique id for this audio slice. Will not be present if audio has not been inserted
resource_url: StringThe audio resource this audio slice is taken from, generally pulled from the DRS API
parent_track: Option<DocumentAudioId>An audio slice this slice is a subunit of, if there is one
recorded_at: Option<Date>When the track was recorded, if available
recorded_by: Option<User>Which user recorded the tracked, if uploaded by a user
include_in_edited_collection: boolTrue if audio should be shown to Readers.
edited_by: Option<User>Last Editor to decide if audio should be included in edited collection.
annotations: Option<Vec<AudioSlice>>The annotations for subunits of this slice, if there are any
index: i32This slice’s relative position to other slices within an audio resource
start_time: Option<i32>The time (in seconds) in the parent track where this slice begins.
end_time: Option<i32>The time (in seconds) in the parent track where this slice ends.
Implementations
sourceimpl AudioSlice
impl AudioSlice
pub async fn slice_id(&self, ctx: &Context<'_>) -> Result<&Option<AudioSliceId>>
pub async fn resource_url(&self, ctx: &Context<'_>) -> Result<&String>
pub async fn parent_track( &self, ctx: &Context<'_>, ) -> Result<&Option<DocumentAudioId>>
pub async fn recorded_at(&self, ctx: &Context<'_>) -> Result<&Option<Date>>
pub async fn recorded_by(&self, ctx: &Context<'_>) -> Result<&Option<User>>
pub async fn include_in_edited_collection( &self, ctx: &Context<'_>, ) -> Result<&bool>
pub async fn edited_by(&self, ctx: &Context<'_>) -> Result<&Option<User>>
pub async fn index(&self, ctx: &Context<'_>) -> Result<&i32>
pub async fn start_time(&self, ctx: &Context<'_>) -> Result<&Option<i32>>
pub async fn end_time(&self, ctx: &Context<'_>) -> Result<&Option<i32>>