dailp

Struct Database

source
pub struct Database { /* private fields */ }
Connects to our backing database instance, providing high level functions for accessing the data therein.

Implementations

source

impl Database

source

pub async fn genre_for_document( &self, doc_id: Uuid, ) -> Result<Option<Genre>, Error>

source

pub async fn format_for_document( &self, doc_id: Uuid, ) -> Result<Option<Format>, Error>

source

pub async fn keywords_for_documents( &self, doc_ids: Vec<Uuid>, ) -> Result<HashMap<Uuid, Vec<Keyword>>, Error>

source

pub async fn languages_for_documents( &self, doc_ids: Vec<Uuid>, ) -> Result<HashMap<Uuid, Vec<Language>>, Error>

source

pub async fn subject_headings_for_documents( &self, doc_ids: Vec<Uuid>, ) -> Result<HashMap<Uuid, Vec<SubjectHeading>>, Error>

source

pub async fn spatial_coverage_for_documents( &self, doc_ids: Vec<Uuid>, ) -> Result<HashMap<Uuid, Vec<SpatialCoverage>>, Error>

source

pub async fn creators_for_documents( &self, doc_ids: Vec<Uuid>, ) -> Result<HashMap<Uuid, Vec<Creator>>, Error>

source

pub async fn creators_for_document( &self, doc_id: Uuid, ) -> Result<Vec<Creator>, Error>

source

pub async fn keywords_for_document( &self, doc_id: Uuid, ) -> Result<Vec<Keyword>, Error>

source

pub async fn languages_for_document( &self, doc_id: Uuid, ) -> Result<Vec<Language>, Error>

source

pub async fn subject_headings_for_document( &self, doc_id: Uuid, ) -> Result<Vec<SubjectHeading>, Error>

source

pub async fn spatial_coverage_for_document( &self, doc_id: Uuid, ) -> Result<Vec<SpatialCoverage>, Error>

source

pub fn connect(num_connections: Option<u32>) -> Result<Self>

source

pub async fn comment_by_id(&self, comment_id: &Uuid) -> Result<Comment>

Get a specific comment by id

source

pub async fn comments_by_parent( &self, parent_id: &Uuid, parent_type: &CommentParentType, ) -> Result<Vec<Comment>>

Get all comments on a given object

source

pub async fn insert_comment( &self, posted_by: &Uuid, text_content: String, parent_id: &Uuid, parent_type: &CommentParentType, comment_type: &Option<CommentType>, ) -> Result<Uuid>

Insert a new comment into the database

source

pub async fn delete_comment(&self, comment_id: &Uuid) -> Result<Uuid>

Delete a comment from the database

source

pub async fn paragraph_by_id( &self, paragraph_id: &Uuid, ) -> Result<DocumentParagraph>

source

pub async fn word_by_id(&self, word_id: &Uuid) -> Result<AnnotatedForm>

source

pub async fn upsert_contributor(&self, person: ContributorDetails) -> Result<()>

source

pub async fn potential_syllabary_matches( &self, syllabary: &str, ) -> Result<Vec<AnnotatedForm>>

source

pub async fn connected_forms( &self, document_id: Option<DocumentId>, gloss: &str, ) -> Result<Vec<AnnotatedForm>>

source

pub async fn morphemes( &self, morpheme_id: MorphemeId, _compare_by: Option<CherokeeOrthography>, ) -> Result<Vec<MorphemeReference>>

source

pub async fn word_contributor_audio( &self, word_id: &Uuid, ) -> Result<Vec<AudioSlice>>

source

pub async fn document_contributor_audio( &self, document_id: &Uuid, ) -> Result<Vec<AudioSlice>>

source

pub async fn words_by_doc( &self, document_id: Option<DocumentId>, gloss: &str, ) -> Result<Vec<WordsInDocument>>

source

pub async fn all_documents(&self) -> Result<Vec<AnnotatedDoc>>

source

pub async fn upsert_image_source(&self, title: &str, url: &str) -> Result<Uuid>

source

pub async fn image_source_by_title( &self, title: &str, ) -> Result<Option<ImageSource>>

source

pub async fn image_source_by_id( &self, id: ImageSourceId, ) -> Result<Option<ImageSource>>

source

pub async fn upsert_collection( &self, collection: &EditedCollection, ) -> Result<String>

source

pub async fn insert_all_chapters( &self, chapters: Vec<CollectionChapter>, slug: String, ) -> Result<String>

source

pub async fn document_manifest( &self, _document_name: &str, url: String, ) -> Result<Manifest>

source

pub async fn all_tags( &self, system: CherokeeOrthography, ) -> Result<Vec<MorphemeTag>>

source

pub async fn search_words_any_field( &self, query: String, ) -> Result<Vec<AnnotatedForm>>

source

pub async fn top_collections(&self) -> Result<Vec<DocumentCollection>>

source

pub async fn all_edited_collections(&self) -> Result<Vec<EditedCollection>>

source

pub async fn upsert_dailp_user(&self, user_id: Uuid) -> Result<Uuid>

Ensure that a user exists in the database user_id should be a congnito sub claim

source

pub async fn update_dailp_user(&self, user: UserUpdate) -> Result<Uuid>

source

pub async fn dailp_user_by_id(&self, user_id: &Uuid) -> Result<User>

source

pub async fn update_annotation(&self, _annote: Annotation) -> Result<()>

source

pub async fn update_word(&self, word: AnnotatedFormUpdate) -> Result<Uuid>

source

pub async fn add_bookmark( &self, document_id: Uuid, user_id: Uuid, ) -> Result<String>

source

pub async fn remove_bookmark( &self, document_id: Uuid, user_id: Uuid, ) -> Result<String>

source

pub async fn all_users(&self) -> Result<Vec<User>>

source

pub async fn bookmarked_documents(&self, user_id: &Uuid) -> Result<Vec<Uuid>>

source

pub async fn get_document_bookmarked_on( &self, document_id: &Uuid, user_id: &Uuid, ) -> Result<Option<Date>>

source

pub async fn attach_audio_to_word( &self, upload: &AttachAudioToWordInput, contributor_id: &Uuid, ) -> Result<Uuid>

This does two things:

  1. Create a media slice if one does not exist for the provided audio recording.
  2. Add a join table entry attaching that media slice to the specified word.

Returns the id of the upserted media slice

source

pub async fn attach_audio_to_document( &self, upload: &AttachAudioToDocumentInput, contributor_id: &Uuid, ) -> Result<Uuid>

As above in attach_audio_to_word: Creates media slice if doesn’t yet exist for provided audio recording. Adds join table entry attaching media slice to document. Returns id of upserted media slice.

source

pub async fn update_word_audio_visibility( &self, word_id: &Uuid, audio_slice_id: &Uuid, include_in_edited_collection: bool, editor_id: &Uuid, ) -> Result<Option<Uuid>>

Update if a piece of word audio will be shown to readers Will return None if the word and audio assocation could not be found, otherwise word id.

source

pub async fn update_document_audio_visibility( &self, document_id: &Uuid, audio_slice_id: &Uuid, include_in_edited_collection: bool, editor_id: &Uuid, ) -> Result<Option<Uuid>>

Update if a piece of document audio will be shown to readers Will return None if the document and audio assocation could not be found, otherwise document id.

source

pub async fn update_document_metadata( &self, document: DocumentMetadataUpdate, ) -> Result<Uuid>

source

pub async fn update_paragraph( &self, paragraph: ParagraphUpdate, ) -> Result<DocumentParagraph>

source

pub async fn update_comment( &self, comment: CommentUpdate, ) -> Result<Uuid, Error>

source

pub async fn update_contributor_attribution( &self, contribution: UpdateContributorAttribution, ) -> Result<Uuid>

source

pub async fn delete_contributor_attribution( &self, contribution: DeleteContributorAttribution, ) -> Result<Uuid>

source

pub async fn all_pages(&self) -> Result<Vec<Page>>

source

pub async fn update_page(&self, _page: Page) -> Result<()>

source

pub async fn words_in_document( &self, document_id: DocumentId, start: Option<i64>, end: Option<i64>, ) -> Result<impl Iterator<Item = AnnotatedForm>>

source

pub async fn count_words_in_document( &self, document_id: DocumentId, ) -> Result<i64>

source

pub async fn documents_in_collection( &self, _super_collection: &str, collection: &str, ) -> Result<Vec<DocumentReference>>

source

pub async fn insert_top_collection( &self, title: String, _index: i64, ) -> Result<Uuid>

source

pub async fn insert_dictionary_document( &self, document: &DocumentMetadata, ) -> Result<DocumentId>

source

pub async fn insert_document( &self, meta: &DocumentMetadata, collection_id: Uuid, index_in_collection: i64, ) -> Result<DocumentId>

source

pub async fn insert_document_contents( &self, document: AnnotatedDoc, ) -> Result<()>

source

pub async fn insert_edited_collection( &self, collection: CreateEditedCollectionInput, ) -> Result<Uuid>

source

pub async fn document_breadcrumbs( &self, document_id: DocumentId, _super_collection: &str, ) -> Result<Vec<DocumentCollection>>

source

pub async fn chapter_breadcrumbs( &self, path: Vec<String>, ) -> Result<Vec<DocumentCollection>>

source

pub async fn insert_one_word(&self, form: AnnotatedForm) -> Result<()>

source

pub async fn insert_lexical_entries( &self, document_id: DocumentId, stems: Vec<AnnotatedForm>, surface_forms: Vec<AnnotatedForm>, ) -> Result<()>

source

pub async fn only_insert_words( &self, document_id: DocumentId, forms: Vec<AnnotatedForm>, ) -> Result<()>

source

pub async fn insert_lexical_words<'a>( &self, tx: &mut Transaction<'a, Postgres>, forms: Vec<AnnotatedForm>, ) -> Result<()>

source

pub async fn insert_word<'a>( &self, tx: &mut Transaction<'a, Postgres>, form: AnnotatedForm, document_id: Uuid, page_id: Option<Uuid>, char_range: Option<PgRange<i64>>, ) -> Result<Uuid>

This is only used for

source

pub async fn insert_morpheme_system( &self, short_name: String, title: String, ) -> Result<Uuid>

source

pub async fn insert_abstract_tag(&self, tag: AbstractMorphemeTag) -> Result<()>

source

pub async fn insert_custom_abstract_tag( &self, tag: AbstractMorphemeTag, ) -> Result<Uuid>

source

pub async fn insert_custom_morpheme_tag( &self, form: MorphemeTag, system_id: Uuid, ) -> Result<()>

source

pub async fn insert_morpheme_tag( &self, form: MorphemeTag, system_id: Uuid, ) -> Result<()>

source

pub async fn document_id_from_name( &self, short_name: &str, ) -> Result<Option<DocumentId>>

source

pub async fn insert_morpheme_relations( &self, links: Vec<LexicalConnection>, ) -> Result<()>

source

pub async fn collection(&self, slug: String) -> Result<DocumentCollection>

source

pub async fn document_group_id_by_slug( &self, slug: &str, ) -> Result<Option<Uuid>>

source

pub async fn collection_slug_by_id( &self, collection_id: Uuid, ) -> Result<Option<String>>

Get collection slug by collection ID

source

pub async fn chapter( &self, collection_slug: String, chapter_slug: String, ) -> Result<Option<CollectionChapter>>

source

pub async fn chapters_by_document( &self, document_slug: String, ) -> Result<Option<Vec<CollectionChapter>>>

source

pub async fn insert_chapter_contributor_attribution( &self, chapter_id: &Uuid, contributor_id: &Uuid, contribution_role: &str, ) -> Result<()>

Insert a contributor attribution for a chapter

source

pub async fn insert_document_into_edited_collection( &self, document: AnnotatedDoc, collection_id: Uuid, ) -> Result<(DocumentId, Uuid)>

Insert a document into an edited collection and create a new chapter for it Returns (document_id, chapter_id) dennis todo : please clean this up

source

pub async fn abbreviation_id_from_short_name( &self, short_name: &str, ) -> Result<Uuid>

source

pub async fn upsert_page(&self, input: NewPageInput) -> Result<String>

source

pub async fn page_by_path(&self, path: &str) -> Result<Option<Page>>

source

pub async fn get_menu_by_slug(&self, slug: String) -> Result<Menu>

source

pub async fn update_menu(&self, menu: MenuUpdate) -> Result<Menu>

source

pub async fn insert_menu(&self, menu: Menu) -> Result<()>