dailp

Struct Date

source
pub struct Date(pub NaiveDate);
Internal Date type which wraps a reliable date library. Adds SQL and GraphQL support to the type.

Tuple Fields

0: NaiveDate

Implementations

source

impl Date

source

pub fn new(internal: NaiveDate) -> Self

Make a new date from an underlying date object.

source

pub fn from_ymd(year: i32, month: u32, day: u32) -> Self

Make a new date from year, month, and day integers.

source

pub fn parse(s: &str) -> Result<Self, ParseError>

Parse a date from a string like “1999-12-31”

source

impl Date

source

pub async fn year(&self, _: &Context<'_>) -> Result<i32>

The year of this date

source

pub async fn month(&self, _: &Context<'_>) -> Result<u32>

The month of this date

source

pub async fn day(&self, _: &Context<'_>) -> Result<u32>

The day of this date

source

pub async fn formatted_date(&self, _: &Context<'_>) -> Result<String>

Formatted version of the date for humans to read