pub struct DeleteContributorAttribution {
pub document_id: Uuid,
pub contributor_id: Uuid,
}Expand description
Delete a contributor attribution for a document based on the two ids
Fields
document_id: UuidThe document to perform this operation on
contributor_id: UuidThe UUID of the contributor to remove from this document’s attributions