pub struct DocumentAudioId(pub String);Expand description
A unique identifier for audio slices
Tuple Fields
0: StringTrait Implementations
sourceimpl Clone for DocumentAudioId
impl Clone for DocumentAudioId
sourcefn clone(&self) -> DocumentAudioId
fn clone(&self) -> DocumentAudioId
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for DocumentAudioId
impl Debug for DocumentAudioId
sourceimpl<'de> Deserialize<'de> for DocumentAudioId
impl<'de> Deserialize<'de> for DocumentAudioId
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl From<String> for DocumentAudioId
impl From<String> for DocumentAudioId
sourceimpl Hash for DocumentAudioId
impl Hash for DocumentAudioId
sourceimpl InputType for DocumentAudioId
impl InputType for DocumentAudioId
sourcetype RawValueType = String
type RawValueType = String
The raw type used for validator. Read more
sourcefn create_type_info(registry: &mut Registry) -> String
fn create_type_info(registry: &mut Registry) -> String
Create type information in the registry and return qualified typename.
sourcefn parse(value: Option<Value>) -> InputValueResult<Self>
fn parse(value: Option<Value>) -> InputValueResult<Self>
Parse from
Value. None represents undefined.sourcefn as_raw_value(&self) -> Option<&Self::RawValueType>
fn as_raw_value(&self) -> Option<&Self::RawValueType>
Returns a reference to the raw value.
fn qualified_type_name() -> String
fn qualified_type_name() -> String
Qualified typename.
sourceimpl Into<String> for DocumentAudioId
impl Into<String> for DocumentAudioId
sourceimpl OutputType for DocumentAudioId
impl OutputType for DocumentAudioId
sourcefn create_type_info(registry: &mut Registry) -> String
fn create_type_info(registry: &mut Registry) -> String
Create type information in the registry and return qualified typename.
sourcefn resolve<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
_: &'life1 ContextSelectionSet<'life2>,
_field: &'life3 Positioned<Field>,
) -> Pin<Box<dyn Future<Output = ServerResult<Value>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn resolve<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
_: &'life1 ContextSelectionSet<'life2>,
_field: &'life3 Positioned<Field>,
) -> Pin<Box<dyn Future<Output = ServerResult<Value>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Resolve an output value to
async_graphql::Value.fn qualified_type_name() -> String
fn qualified_type_name() -> String
Qualified typename.
fn introspection_type_name(&self) -> Cow<'static, str>
fn introspection_type_name(&self) -> Cow<'static, str>
Introspection type name Read more
sourceimpl PartialEq for DocumentAudioId
impl PartialEq for DocumentAudioId
sourceimpl ScalarType for DocumentAudioId
impl ScalarType for DocumentAudioId
sourceimpl Serialize for DocumentAudioId
impl Serialize for DocumentAudioId
impl Eq for DocumentAudioId
impl StructuralPartialEq for DocumentAudioId