pub struct DocumentId(pub Uuid);Expand description
Database ID for one document
Tuple Fields
0: UuidTrait Implementations
sourceimpl Clone for DocumentId
impl Clone for DocumentId
sourcefn clone(&self) -> DocumentId
fn clone(&self) -> DocumentId
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for DocumentId
impl Debug for DocumentId
sourceimpl Default for DocumentId
impl Default for DocumentId
sourcefn default() -> DocumentId
fn default() -> DocumentId
Returns the “default value” for a type. Read more
sourceimpl<'de> Deserialize<'de> for DocumentId
impl<'de> Deserialize<'de> for DocumentId
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl From<Uuid> for DocumentId
impl From<Uuid> for DocumentId
sourceimpl Hash for DocumentId
impl Hash for DocumentId
sourceimpl InputType for DocumentId
impl InputType for DocumentId
sourcetype RawValueType = Uuid
type RawValueType = Uuid
The raw type used for validator. Read more
sourcefn create_type_info(registry: &mut Registry) -> String
fn create_type_info(registry: &mut Registry) -> String
Create type information in the registry and return qualified typename.
sourcefn parse(value: Option<Value>) -> InputValueResult<Self>
fn parse(value: Option<Value>) -> InputValueResult<Self>
Parse from
Value. None represents undefined.sourcefn as_raw_value(&self) -> Option<&Self::RawValueType>
fn as_raw_value(&self) -> Option<&Self::RawValueType>
Returns a reference to the raw value.
fn qualified_type_name() -> String
fn qualified_type_name() -> String
Qualified typename.
sourceimpl Into<Uuid> for DocumentId
impl Into<Uuid> for DocumentId
sourceimpl Loader<DocumentId> for Database
impl Loader<DocumentId> for Database
sourcetype Value = AnnotatedDoc
type Value = AnnotatedDoc
type of value.
sourcefn load<'life0, 'life1, 'async_trait>(
&'life0 self,
keys: &'life1 [DocumentId],
) -> Pin<Box<dyn Future<Output = Result<HashMap<DocumentId, Self::Value>, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn load<'life0, 'life1, 'async_trait>(
&'life0 self,
keys: &'life1 [DocumentId],
) -> Pin<Box<dyn Future<Output = Result<HashMap<DocumentId, Self::Value>, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Load the data set specified by the
keys.sourceimpl OutputType for DocumentId
impl OutputType for DocumentId
sourcefn create_type_info(registry: &mut Registry) -> String
fn create_type_info(registry: &mut Registry) -> String
Create type information in the registry and return qualified typename.
sourcefn resolve<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
_: &'life1 ContextSelectionSet<'life2>,
_field: &'life3 Positioned<Field>,
) -> Pin<Box<dyn Future<Output = ServerResult<Value>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn resolve<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
_: &'life1 ContextSelectionSet<'life2>,
_field: &'life3 Positioned<Field>,
) -> Pin<Box<dyn Future<Output = ServerResult<Value>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Resolve an output value to
async_graphql::Value.fn qualified_type_name() -> String
fn qualified_type_name() -> String
Qualified typename.
fn introspection_type_name(&self) -> Cow<'static, str>
fn introspection_type_name(&self) -> Cow<'static, str>
Introspection type name Read more
sourceimpl PartialEq for DocumentId
impl PartialEq for DocumentId
sourceimpl ScalarType for DocumentId
impl ScalarType for DocumentId
sourceimpl Serialize for DocumentId
impl Serialize for DocumentId
impl Copy for DocumentId
impl Eq for DocumentId
impl StructuralPartialEq for DocumentId