pub struct DocumentMetadataUpdate {
pub id: Uuid,
pub title: MaybeUndefined<String>,
pub written_at: MaybeUndefined<DateInput>,
pub keywords: MaybeUndefined<Vec<KeywordUpdate>>,
pub languages: MaybeUndefined<Vec<LanguageUpdate>>,
pub subject_headings: MaybeUndefined<Vec<SubjectHeadingUpdate>>,
pub contributors: MaybeUndefined<Vec<ContributorAttributionInput>>,
pub spatial_coverage: MaybeUndefined<Vec<SpatialCoverageUpdate>>,
pub creators: MaybeUndefined<Vec<CreatorUpdate>>,
pub format: MaybeUndefined<FormatUpdate>,
pub genre: MaybeUndefined<GenreUpdate>,
}Expand description
Used for updating document metadata. All fields except id are optional.
Fields
id: UuidThe ID of the document to update
title: MaybeUndefined<String>An updated title for this document, or nothing (if title is unchanged)
written_at: MaybeUndefined<DateInput>The date this document was written, or nothing (if unchanged or not applicable)
keywords: MaybeUndefined<Vec<KeywordUpdate>>The key terms associated with the document
languages: MaybeUndefined<Vec<LanguageUpdate>>The languages present in the document
subject_headings: MaybeUndefined<Vec<SubjectHeadingUpdate>>Terms that reflect Indigenous knowledge practices associated with the document
contributors: MaybeUndefined<Vec<ContributorAttributionInput>>The editors, translators, etc. of the document
spatial_coverage: MaybeUndefined<Vec<SpatialCoverageUpdate>>The physical locations associated with a document (e.g. where it was written, found)
creators: MaybeUndefined<Vec<CreatorUpdate>>The creator(s) of the document
format: MaybeUndefined<FormatUpdate>The format of the original artifact
genre: MaybeUndefined<GenreUpdate>Term that contextualizes the social practice surrounding the document