pub struct Geometry { /* private fields */ }Expand description
A rectangle slice of something, usually a large document image.
Units are a percentage of the containing document. This is more useful than pixels because we can more easily compare geometries between images of different resolutions. For example, we could identify all items in any bottom-right corner with Geometry(90%, 90%, 100%, 100%). Physical units would be better, but IIIF only allows pixels and percentages.
Potential use case: Each document is represented by an ordered list of [AnnotatedForm]s. Each form has some geometry on the source image. There are a bunch of other annotations on the source image that are unordered. These may be specific syllabary characters, notes about the handwriting, etc. Using MongoDB comparison queries, we can request a list of all spatial annotations on the same document that lie within or around the geometry of this specific word.
Implementations
sourceimpl Geometry
impl Geometry
sourcepub fn new(x_min: f64, y_min: f64, x_max: f64, y_max: f64) -> Self
pub fn new(x_min: f64, y_min: f64, x_max: f64, y_max: f64) -> Self
Make a new rectangle with coordinates in percentage units of the containing document.
sourcepub fn to_iiif_string(&self) -> String
pub fn to_iiif_string(&self) -> String
Usable in IIIF URL queries.
sourcepub fn to_selector_string(&self) -> String
pub fn to_selector_string(&self) -> String
Usable in IIIF API calls.