pub struct MorphemeTag {
pub internal_tags: Vec<String>,
pub tag: String,
pub title: String,
pub shape: Option<String>,
pub details_url: Option<String>,
pub definition: String,
pub morpheme_type: String,
pub role_override: Option<WordSegmentRole>,
}Expand description
A concrete representation of a particular functional morpheme.
Fields
Internal representation of this functional item, which may be one or more word parts in the raw annotation. For example, [“X”, “Y”] could map to “Z” in a particular display format.
tag: StringHow this morpheme is represented in a gloss
title: StringPlain English title of the morpheme tag
shape: Option<String>How this morpheme looks in original language data
details_url: Option<String>URL to an external page with more details about this morpheme.
definition: StringA prose description of what this morpheme means and how it works in context.
morpheme_type: StringWhat kind of morpheme is this? Examples are “Prepronominal Prefix” or “Aspectual Suffix”
role_override: Option<WordSegmentRole>Overrides the segment type of instances of this tag.
Implementations
sourceimpl MorphemeTag
impl MorphemeTag
pub async fn tag(&self, ctx: &Context<'_>) -> Result<&String>
pub async fn title(&self, ctx: &Context<'_>) -> Result<&String>
pub async fn shape(&self, ctx: &Context<'_>) -> Result<&Option<String>>
pub async fn details_url(&self, ctx: &Context<'_>) -> Result<&Option<String>>
pub async fn definition(&self, ctx: &Context<'_>) -> Result<&String>
pub async fn morpheme_type(&self, ctx: &Context<'_>) -> Result<&String>
pub async fn role_override( &self, ctx: &Context<'_>, ) -> Result<&Option<WordSegmentRole>>