pub struct PositionInDocument {
pub document_id: DocumentId,
pub page_number: String,
pub index: i64,
pub geometry: Option<Geometry>,
}Expand description
The reference position within a document of one specific form
Fields
document_id: DocumentIdWhat document is this item within?
page_number: StringWhat page is it on (starting from 1)? May be a single page or range of pages.
index: i64How many items come before this one in the whole document?
1-indexed position indicating where the form sits in the ordering of all forms in the document. Used for relative ordering of forms from the same document.
geometry: Option<Geometry>What section of the document image corresponds to this item?
Implementations
sourceimpl PositionInDocument
impl PositionInDocument
pub async fn document_id(&self, ctx: &Context<'_>) -> Result<&DocumentId>
pub async fn page_number(&self, ctx: &Context<'_>) -> Result<&String>
pub async fn index(&self, ctx: &Context<'_>) -> Result<&i64>
pub async fn geometry(&self, ctx: &Context<'_>) -> Result<&Option<Geometry>>
sourceimpl PositionInDocument
impl PositionInDocument
sourcepub fn new(document_id: DocumentId, page_number: String, index: i64) -> Self
pub fn new(document_id: DocumentId, page_number: String, index: i64) -> Self
Make a new document position from the document ID, page number, and item index.
sourcepub fn make_id(&self, gloss: &str, use_index: bool) -> String
pub fn make_id(&self, gloss: &str, use_index: bool) -> String
Make a unique ID to identify a string at this position, clearing all non-ASCII characters from the given string.
sourcepub fn make_raw_id(&self, raw_gloss: &str, use_index: bool) -> String
pub fn make_raw_id(&self, raw_gloss: &str, use_index: bool) -> String
Converts the input into a suitable ID format by stripping whitespace and punctuation before putting the document ID before it.
sourcepub fn make_form_id(&self, segments: &[WordSegment]) -> String
pub fn make_form_id(&self, segments: &[WordSegment]) -> String
Create a rough URI-like string for this word with the given morphemic segmentation.