pub struct WordSegment {
pub system: Option<CherokeeOrthography>,
pub morpheme: String,
pub gloss: String,
pub gloss_id: Option<Uuid>,
pub role: WordSegmentRole,
pub matching_tag: Option<MorphemeTag>,
}Expand description
A single unit of meaning and its corresponding English gloss.
Fields
system: Option<CherokeeOrthography>Which Cherokee representation system is this segment written with?
morpheme: StringSource language representation of this segment.
gloss: StringTarget language representation of this segment.
gloss_id: Option<Uuid>Database ID for the associated gloss, which may be shared by several morphemes in the same document.
role: WordSegmentRoleWhat kind of thing is the next segment?
This field determines what character should separate this segment from the next one when reconstituting a full segmentation string.
matching_tag: Option<MorphemeTag>Optional glossary entry for this segment which gives further information, like a definition and example usages.
Implementations
sourceimpl WordSegment
impl WordSegment
sourcepub fn new(
morpheme: String,
gloss: String,
role: Option<WordSegmentRole>,
) -> Self
pub fn new( morpheme: String, gloss: String, role: Option<WordSegmentRole>, ) -> Self
Make a new morpheme segment
sourcepub fn parse_many(morpheme_layer: &str, gloss_layer: &str) -> Option<Vec<Self>>
pub fn parse_many(morpheme_layer: &str, gloss_layer: &str) -> Option<Vec<Self>>
Parse all segments from a raw interlinear morphemic segmentation. The first argument is the segmented source, while the second argument is the target language gloss of each segment.
sourcepub fn get_previous_separator(&self) -> &str
pub fn get_previous_separator(&self) -> &str
The separator that should follow this segment, based on the type of the next segment.
sourcepub fn gloss_layer<'a>(
segments: impl IntoIterator<Item = &'a WordSegment>,
) -> String
pub fn gloss_layer<'a>( segments: impl IntoIterator<Item = &'a WordSegment>, ) -> String
Build a string of the morpheme gloss line, used in interlinear gloss text (IGT).
sourcepub fn get_morpheme(&self) -> Cow<'_, str>
pub fn get_morpheme(&self) -> Cow<'_, str>
Convert the source representation of this segment into the given phonemic writing system.