dailp

Trait MaybeUndefinedExt

source
pub trait MaybeUndefinedExt<T> {
    // Required method
    fn into_vec(self) -> Vec<Option<T>>;
}
Trait that defines function which takes in a possibly undefined value.

Required Methods

source

fn into_vec(self) -> Vec<Option<T>>

If the given value is undefined, convert into a vector of option. Otherwise, return an empty vector.

Implementations on Foreign Types

source

impl<T> MaybeUndefinedExt<T> for MaybeUndefined<T>

source

fn into_vec(self) -> Vec<Option<T>>

Implementors