pub enum CommentParentType {
Word,
Paragraph,
}Expand description
An enum listing the possible types that a comment could be attached to
Variants
Implementations
sourceimpl CommentParentType
impl CommentParentType
sourcepub async fn resolve(
&self,
db: &Database,
parent_id: &Uuid,
) -> FieldResult<CommentParent>
pub async fn resolve( &self, db: &Database, parent_id: &Uuid, ) -> FieldResult<CommentParent>
Get the actual object referenced by this type, given an id