pub struct AnnotatedDoc {
pub meta: DocumentMetadata,
pub segments: Option<Vec<TranslatedPage>>,
}Expand description
A document with associated metadata and content broken down into pages and further into paragraphs with an English translation. Also supports each word being broken down into component parts and having associated notes.
Fields
meta: DocumentMetadataAll non-content metadata about this document
segments: Option<Vec<TranslatedPage>>The meat of the document, all the pages which contain its contents.
Implementations
sourceimpl AnnotatedDoc
impl AnnotatedDoc
sourcepub fn new(
meta: DocumentMetadata,
segments: Vec<Vec<Vec<AnnotatedSeg>>>,
) -> Self
pub fn new( meta: DocumentMetadata, segments: Vec<Vec<Vec<AnnotatedSeg>>>, ) -> Self
Build a document from its metadata and raw contents.