pub struct ContributorDetails {
pub full_name: String,
pub alternate_name: Option<String>,
pub birth_date: Option<Date>,
pub is_visible: bool,
}Expand description
Basic personal details of an individual contributor, which can be retrieved
from a particular instance of Contributor.
They may have transcribed a handwritten manuscript, translated it into English, or analyzed it for linguistic information. This information can be used to track who contributed to the development of each individual document, and track contributions to the archive as a whole.
Fields
full_name: StringFull name of this person, this exact string must be used to identify them elsewhere, like in the attribution for a particular document.
alternate_name: Option<String>Alternate name of this person, may be in a different language or writing system. Used only for descriptive purposes.
birth_date: Option<Date>The optional date that this contributor was born on.
is_visible: boolWhether or not the contributor’s profile is linked to their contributions
Implementations
sourceimpl ContributorDetails
impl ContributorDetails
pub async fn full_name(&self, ctx: &Context<'_>) -> Result<&String>
pub async fn alternate_name(&self, ctx: &Context<'_>) -> Result<&Option<String>>
pub async fn birth_date(&self, ctx: &Context<'_>) -> Result<&Option<Date>>
pub async fn is_visible(&self, ctx: &Context<'_>) -> Result<&bool>