pub struct Database { /* private fields */ }Expand description
Connects to our backing database instance, providing high level functions for accessing the data therein.
Implementations
sourceimpl Database
impl Database
pub async fn genre_for_document( &self, doc_id: Uuid, ) -> Result<Option<Genre>, Error>
pub async fn format_for_document( &self, doc_id: Uuid, ) -> Result<Option<Format>, Error>
pub async fn keywords_for_documents( &self, doc_ids: Vec<Uuid>, ) -> Result<HashMap<Uuid, Vec<Keyword>>, Error>
pub async fn languages_for_documents( &self, doc_ids: Vec<Uuid>, ) -> Result<HashMap<Uuid, Vec<Language>>, Error>
pub async fn subject_headings_for_documents( &self, doc_ids: Vec<Uuid>, ) -> Result<HashMap<Uuid, Vec<SubjectHeading>>, Error>
pub async fn spatial_coverage_for_documents( &self, doc_ids: Vec<Uuid>, ) -> Result<HashMap<Uuid, Vec<SpatialCoverage>>, Error>
pub async fn creators_for_documents( &self, doc_ids: Vec<Uuid>, ) -> Result<HashMap<Uuid, Vec<Creator>>, Error>
pub async fn creators_for_document( &self, doc_id: Uuid, ) -> Result<Vec<Creator>, Error>
pub async fn keywords_for_document( &self, doc_id: Uuid, ) -> Result<Vec<Keyword>, Error>
pub async fn languages_for_document( &self, doc_id: Uuid, ) -> Result<Vec<Language>, Error>
pub async fn subject_headings_for_document( &self, doc_id: Uuid, ) -> Result<Vec<SubjectHeading>, Error>
pub async fn spatial_coverage_for_document( &self, doc_id: Uuid, ) -> Result<Vec<SpatialCoverage>, Error>
pub fn connect(num_connections: Option<u32>) -> Result<Self>
sourcepub async fn comment_by_id(&self, comment_id: &Uuid) -> Result<Comment>
pub async fn comment_by_id(&self, comment_id: &Uuid) -> Result<Comment>
Get a specific comment by id
sourcepub async fn comments_by_parent(
&self,
parent_id: &Uuid,
parent_type: &CommentParentType,
) -> Result<Vec<Comment>>
pub async fn comments_by_parent( &self, parent_id: &Uuid, parent_type: &CommentParentType, ) -> Result<Vec<Comment>>
Get all comments on a given object
sourcepub async fn insert_comment(
&self,
posted_by: &Uuid,
text_content: String,
parent_id: &Uuid,
parent_type: &CommentParentType,
comment_type: &Option<CommentType>,
) -> Result<Uuid>
pub async fn insert_comment( &self, posted_by: &Uuid, text_content: String, parent_id: &Uuid, parent_type: &CommentParentType, comment_type: &Option<CommentType>, ) -> Result<Uuid>
Insert a new comment into the database
sourcepub async fn delete_comment(&self, comment_id: &Uuid) -> Result<Uuid>
pub async fn delete_comment(&self, comment_id: &Uuid) -> Result<Uuid>
Delete a comment from the database
pub async fn paragraph_by_id( &self, paragraph_id: &Uuid, ) -> Result<DocumentParagraph>
pub async fn word_by_id(&self, word_id: &Uuid) -> Result<AnnotatedForm>
pub async fn upsert_contributor(&self, person: ContributorDetails) -> Result<()>
pub async fn potential_syllabary_matches( &self, syllabary: &str, ) -> Result<Vec<AnnotatedForm>>
pub async fn connected_forms( &self, document_id: Option<DocumentId>, gloss: &str, ) -> Result<Vec<AnnotatedForm>>
pub async fn morphemes( &self, morpheme_id: MorphemeId, _compare_by: Option<CherokeeOrthography>, ) -> Result<Vec<MorphemeReference>>
pub async fn word_contributor_audio( &self, word_id: &Uuid, ) -> Result<Vec<AudioSlice>>
pub async fn document_contributor_audio( &self, document_id: &Uuid, ) -> Result<Vec<AudioSlice>>
pub async fn words_by_doc( &self, document_id: Option<DocumentId>, gloss: &str, ) -> Result<Vec<WordsInDocument>>
pub async fn all_documents(&self) -> Result<Vec<AnnotatedDoc>>
pub async fn upsert_image_source(&self, title: &str, url: &str) -> Result<Uuid>
pub async fn image_source_by_title( &self, title: &str, ) -> Result<Option<ImageSource>>
pub async fn image_source_by_id( &self, id: ImageSourceId, ) -> Result<Option<ImageSource>>
pub async fn upsert_collection( &self, collection: &EditedCollection, ) -> Result<String>
pub async fn insert_all_chapters( &self, chapters: Vec<CollectionChapter>, slug: String, ) -> Result<String>
pub async fn document_manifest( &self, _document_name: &str, url: String, ) -> Result<Manifest>
pub async fn search_words_any_field( &self, query: String, ) -> Result<Vec<AnnotatedForm>>
pub async fn top_collections(&self) -> Result<Vec<DocumentCollection>>
pub async fn all_edited_collections(&self) -> Result<Vec<EditedCollection>>
sourcepub async fn upsert_dailp_user(&self, user_id: Uuid) -> Result<Uuid>
pub async fn upsert_dailp_user(&self, user_id: Uuid) -> Result<Uuid>
Ensure that a user exists in the database user_id should be a congnito sub claim
pub async fn update_dailp_user(&self, user: UserUpdate) -> Result<Uuid>
pub async fn dailp_user_by_id(&self, user_id: &Uuid) -> Result<User>
pub async fn update_annotation(&self, _annote: Annotation) -> Result<()>
pub async fn update_word(&self, word: AnnotatedFormUpdate) -> Result<Uuid>
pub async fn add_bookmark( &self, document_id: Uuid, user_id: Uuid, ) -> Result<String>
pub async fn remove_bookmark( &self, document_id: Uuid, user_id: Uuid, ) -> Result<String>
pub async fn all_users(&self) -> Result<Vec<User>>
pub async fn bookmarked_documents(&self, user_id: &Uuid) -> Result<Vec<Uuid>>
pub async fn get_document_bookmarked_on( &self, document_id: &Uuid, user_id: &Uuid, ) -> Result<Option<Date>>
sourcepub async fn attach_audio_to_word(
&self,
upload: &AttachAudioToWordInput,
contributor_id: &Uuid,
) -> Result<Uuid>
pub async fn attach_audio_to_word( &self, upload: &AttachAudioToWordInput, contributor_id: &Uuid, ) -> Result<Uuid>
This does two things:
- Create a media slice if one does not exist for the provided audio recording.
- Add a join table entry attaching that media slice to the specified word.
Returns the id of the upserted media slice
sourcepub async fn attach_audio_to_document(
&self,
upload: &AttachAudioToDocumentInput,
contributor_id: &Uuid,
) -> Result<Uuid>
pub async fn attach_audio_to_document( &self, upload: &AttachAudioToDocumentInput, contributor_id: &Uuid, ) -> Result<Uuid>
As above in attach_audio_to_word:
Creates media slice if doesn’t yet exist for provided audio recording.
Adds join table entry attaching media slice to document.
Returns id of upserted media slice.
sourcepub async fn update_word_audio_visibility(
&self,
word_id: &Uuid,
audio_slice_id: &Uuid,
include_in_edited_collection: bool,
editor_id: &Uuid,
) -> Result<Option<Uuid>>
pub async fn update_word_audio_visibility( &self, word_id: &Uuid, audio_slice_id: &Uuid, include_in_edited_collection: bool, editor_id: &Uuid, ) -> Result<Option<Uuid>>
Update if a piece of word audio will be shown to readers Will return None if the word and audio assocation could not be found, otherwise word id.
sourcepub async fn update_document_audio_visibility(
&self,
document_id: &Uuid,
audio_slice_id: &Uuid,
include_in_edited_collection: bool,
editor_id: &Uuid,
) -> Result<Option<Uuid>>
pub async fn update_document_audio_visibility( &self, document_id: &Uuid, audio_slice_id: &Uuid, include_in_edited_collection: bool, editor_id: &Uuid, ) -> Result<Option<Uuid>>
Update if a piece of document audio will be shown to readers Will return None if the document and audio assocation could not be found, otherwise document id.
pub async fn update_document_metadata( &self, document: DocumentMetadataUpdate, ) -> Result<Uuid>
pub async fn update_paragraph( &self, paragraph: ParagraphUpdate, ) -> Result<DocumentParagraph>
pub async fn update_comment( &self, comment: CommentUpdate, ) -> Result<Uuid, Error>
pub async fn update_contributor_attribution( &self, contribution: UpdateContributorAttribution, ) -> Result<Uuid>
pub async fn delete_contributor_attribution( &self, contribution: DeleteContributorAttribution, ) -> Result<Uuid>
pub async fn all_pages(&self) -> Result<Vec<Page>>
pub async fn update_page(&self, _page: Page) -> Result<()>
pub async fn words_in_document( &self, document_id: DocumentId, start: Option<i64>, end: Option<i64>, ) -> Result<impl Iterator<Item = AnnotatedForm>>
pub async fn count_words_in_document( &self, document_id: DocumentId, ) -> Result<i64>
pub async fn documents_in_collection( &self, _super_collection: &str, collection: &str, ) -> Result<Vec<DocumentReference>>
pub async fn insert_top_collection( &self, title: String, _index: i64, ) -> Result<Uuid>
pub async fn insert_dictionary_document( &self, document: &DocumentMetadata, ) -> Result<DocumentId>
pub async fn insert_document( &self, meta: &DocumentMetadata, collection_id: Uuid, index_in_collection: i64, ) -> Result<DocumentId>
pub async fn insert_document_contents( &self, document: AnnotatedDoc, ) -> Result<()>
pub async fn insert_edited_collection( &self, collection: CreateEditedCollectionInput, ) -> Result<Uuid>
pub async fn insert_one_word(&self, form: AnnotatedForm) -> Result<()>
pub async fn insert_lexical_entries( &self, document_id: DocumentId, stems: Vec<AnnotatedForm>, surface_forms: Vec<AnnotatedForm>, ) -> Result<()>
pub async fn only_insert_words( &self, document_id: DocumentId, forms: Vec<AnnotatedForm>, ) -> Result<()>
pub async fn insert_lexical_words<'a>( &self, tx: &mut Transaction<'a, Postgres>, forms: Vec<AnnotatedForm>, ) -> Result<()>
sourcepub async fn insert_word<'a>(
&self,
tx: &mut Transaction<'a, Postgres>,
form: AnnotatedForm,
document_id: Uuid,
page_id: Option<Uuid>,
char_range: Option<PgRange<i64>>,
) -> Result<Uuid>
pub async fn insert_word<'a>( &self, tx: &mut Transaction<'a, Postgres>, form: AnnotatedForm, document_id: Uuid, page_id: Option<Uuid>, char_range: Option<PgRange<i64>>, ) -> Result<Uuid>
This is only used for
pub async fn insert_morpheme_system( &self, short_name: String, title: String, ) -> Result<Uuid>
pub async fn insert_abstract_tag(&self, tag: AbstractMorphemeTag) -> Result<()>
pub async fn insert_custom_abstract_tag( &self, tag: AbstractMorphemeTag, ) -> Result<Uuid>
pub async fn insert_custom_morpheme_tag( &self, form: MorphemeTag, system_id: Uuid, ) -> Result<()>
pub async fn insert_morpheme_tag( &self, form: MorphemeTag, system_id: Uuid, ) -> Result<()>
pub async fn document_id_from_name( &self, short_name: &str, ) -> Result<Option<DocumentId>>
pub async fn insert_morpheme_relations( &self, links: Vec<LexicalConnection>, ) -> Result<()>
pub async fn collection(&self, slug: String) -> Result<DocumentCollection>
pub async fn document_group_id_by_slug( &self, slug: &str, ) -> Result<Option<Uuid>>
sourcepub async fn collection_slug_by_id(
&self,
collection_id: Uuid,
) -> Result<Option<String>>
pub async fn collection_slug_by_id( &self, collection_id: Uuid, ) -> Result<Option<String>>
Get collection slug by collection ID
pub async fn chapter( &self, collection_slug: String, chapter_slug: String, ) -> Result<Option<CollectionChapter>>
pub async fn chapters_by_document( &self, document_slug: String, ) -> Result<Option<Vec<CollectionChapter>>>
sourcepub async fn insert_chapter_contributor_attribution(
&self,
chapter_id: &Uuid,
contributor_id: &Uuid,
contribution_role: &str,
) -> Result<()>
pub async fn insert_chapter_contributor_attribution( &self, chapter_id: &Uuid, contributor_id: &Uuid, contribution_role: &str, ) -> Result<()>
Insert a contributor attribution for a chapter
sourcepub async fn insert_document_into_edited_collection(
&self,
document: AnnotatedDoc,
collection_id: Uuid,
) -> Result<(DocumentId, Uuid)>
pub async fn insert_document_into_edited_collection( &self, document: AnnotatedDoc, collection_id: Uuid, ) -> Result<(DocumentId, Uuid)>
Insert a document into an edited collection and create a new chapter for it Returns (document_id, chapter_id) dennis todo : please clean this up
pub async fn abbreviation_id_from_short_name( &self, short_name: &str, ) -> Result<Uuid>
pub async fn upsert_page(&self, input: NewPageInput) -> Result<String>
pub async fn page_by_path(&self, path: &str) -> Result<Option<Page>>