pub struct DocumentMetadata {Show 19 fields
pub id: DocumentId,
pub short_name: String,
pub title: String,
pub sources: Vec<SourceAttribution>,
pub collection: Option<String>,
pub genre_id: Option<Uuid>,
pub format_id: Option<Uuid>,
pub subject_headings_ids: Option<Vec<Uuid>>,
pub languages_ids: Option<Vec<Uuid>>,
pub keywords_ids: Option<Vec<Uuid>>,
pub creators_ids: Option<Vec<Uuid>>,
pub contributors: Option<Vec<Contributor>>,
pub spatial_coverage_ids: Option<Vec<Uuid>>,
pub translation: Option<Translation>,
pub page_images: Option<IiifImages>,
pub date: Option<Date>,
pub is_reference: bool,
pub audio_recording: Option<AudioSlice>,
pub order_index: i64,
}Expand description
All the metadata associated with one particular document. TODO Make more of these fields on-demand.
Fields
id: DocumentIdDatabase ID
short_name: StringOfficial short identifier.
title: StringFull title of the document.
sources: Vec<SourceAttribution>Further details about this particular document. The original source(s) of this document, the most important first.
collection: Option<String>Where the source document came from, maybe the name of a collection.
genre_id: Option<Uuid>Term that contextualizes the social practice surrounding the document
format_id: Option<Uuid>Term that allows us to trace what the original artifact was
subject_headings_ids: Option<Vec<Uuid>>Terms that reflect Indigenous knowledge practices associated with the document
languages_ids: Option<Vec<Uuid>>The languages present in the document
keywords_ids: Option<Vec<Uuid>>The key terms associated with the document
creators_ids: Option<Vec<Uuid>>The creator(s) of the document
contributors: Option<Vec<Contributor>>The people involved in collecting, translating, annotating.
spatial_coverage_ids: Option<Vec<Uuid>>The physical locations associated with a document (e.g. where it was written, found)
translation: Option<Translation>Rough translation of the document, broken down by paragraph.
page_images: Option<IiifImages>URL for an image of the original physical document.
date: Option<Date>The date this document was produced (or None if unknown)
is_reference: boolWhether this document is a reference, therefore just a list of forms.
audio_recording: Option<AudioSlice>Audio recording of this document, if one exists
order_index: i64Arbitrary number used for manually ordering documents in a collection. For collections without manual ordering, use zero here.