pub trait MaybeUndefinedExt<T> { // Required method fn into_vec(self) -> Vec<Option<T>>; }
Trait that defines function which takes in a possibly undefined value.
If the given value is undefined, convert into a vector of option. Otherwise, return an empty vector.